==> lein-archaic-0.1.1-20140207.065039-6.jar: leiningen/archaic/profiles.clj <==
(ns leiningen.archaic.profiles
  (:require [clojure.string :as str :only (join)]
            (leiningen.archaic.utils [io :refer :all]
                                     [repo :refer (fetch-artifacts resolve-repos)])
            [org.ozias.cljlibs.logging.logging :refer (infoc tracec warnc)]))

(def profile-paths
  [(str (System/getProperty "user.home") "/.lein/profiles.clj")
   (str (System/getProperty "user.home") "/.lein/profiles.d")
   "/etc/leiningen/profiles.clj"])

(defn- parse-profile 
  [file profile ks 
   {:keys [plugins dependencies] :as profmap}
   {:keys [options]}]
  (let [repos (resolve-repos profmap)
        fetcher (fetch-artifacts file repos options)]
    (infoc :green "profile:" :reset " " :yellow profile)
    (tracec :green "repositories:"
            :reset " "
            :yellow (str/join ", " (for [repo repos] (:url repo))))
    (if (or (:all options)(:plugins options))
      (if-let [pres (filter (complement nil?)
                            (fetcher plugins :plugins (conj ks :plugins)))]
        (if (empty? pres)
          (infoc :green"    All plugin versions current")
          (doall pres))))
    (if (or (:all options)(:dependencies options))
      (if-let [dres (filter (complement nil?) 
                            (fetcher dependencies :dependencies (conj ks :dependencies)))]
        (if (empty? dres)
          (infoc :green "    All dependency versions current")
          (dorun dres))))))

(defn- parse-profiles [file args]
  (warnc :green (str "Checking profile(s) (" file ")"))
  (doseq [[profile profmap] (read-profiles-map file args)]
    (parse-profile file (name profile) [profile] profmap args))
  (infoc ""))

(defn- parse-profiled [file args]
  (warnc :green (str "Checking profile ("  file ")"))
  (let [profmap (read-profiles-map file args)
        profname (apply str (take-while #(not (= \. %)) (.getName file)))]
      (parse-profile file profname [] profmap args))
  (infoc ""))

(defn- parse-project-profiles [profiles args]
  (warnc :green "Checking profile(s) (project.clj)")
  (doseq [profile profiles]
    (let [file (exists? "project.clj")
          profname (clojure.core/name (key profile))]
      (parse-profile file profname [:profiles (key profile)] (val profile) args)))
  (infoc ""))

(defn- check-path [path args]
  (if-let [file (exists? path)]
    (cond (.isFile file) (parse-profiles file args)
          (.isDirectory file) (doseq [file (filter (comp not directory?) (file-seq-nh file))]
                                (parse-profiled file args)))
    (infoc :yellow (str "No profile file found at " path "\n"))))

(defn run-task [{:keys [root profiles]} args]
  (let [profile-paths (if (and root (exists? root))
                        (conj profile-paths (str root "/profiles.clj"))
                        profile-paths)]
    (doseq [path profile-paths] (check-path path args))
    (parse-project-profiles profiles args)))

==> lein-archaic-0.3.0-20140209.055045-1.jar: leiningen/archaic/profiles.clj <==
(ns leiningen.archaic.profiles
  (:require [clojure.string :as str :only (join)]
            (leiningen.archaic.utils [io :refer :all]
                                     [repo :refer (fetch-artifacts resolve-repos)])
            [org.ozias.cljlibs.logging.logging :refer (infoc tracec warnc)]))

(def profile-paths
  [(str (System/getProperty "user.home") "/.lein/profiles.clj")
   (str (System/getProperty "user.home") "/.lein/profiles.d")
   "/etc/leiningen/profiles.clj"])

(defn- parse-profile 
  [file profile ks 
   {:keys [plugins dependencies] :as profmap}
   {:keys [options]}]
  (let [repos (resolve-repos profmap)
        fetcher (fetch-artifacts file repos options)]
    (infoc :green "profile:" :reset " " :yellow profile)
    (tracec :green "repositories:"
            :reset " "
            :yellow (str/join ", " (for [repo repos] (:url repo))))
    (if (or (:all options)(:plugins options))
      (if-let [pres (filter (complement nil?)
                            (fetcher plugins :plugins (conj ks :plugins)))]
        (if (empty? pres)
          (infoc :green"    All plugin versions current")
          (doall pres))))
    (if (or (:all options)(:dependencies options))
      (if-let [dres (filter (complement nil?) 
                            (fetcher dependencies :dependencies (conj ks :dependencies)))]
        (if (empty? dres)
          (infoc :green "    All dependency versions current")
          (dorun dres))))))

(defn- parse-profiles [file args]
  (warnc :green "Checking profile(s) (" file ")")
  (doseq [[profile profmap] (read-profiles-map file args)]
    (parse-profile file (name profile) [profile] profmap args))
  (infoc " "))

(defn- parse-profiled [file args]
  (warnc :green "Checking profile ("  file ")")
  (let [profmap (read-profiles-map file args)
        profname (apply str (take-while #(not (= \. %)) (.getName file)))]
      (parse-profile file profname [] profmap args))
  (infoc " "))

(defn- parse-project-profiles [profiles args]
  (warnc :green "Checking profile(s) (project.clj)")
  (doseq [profile profiles]
    (let [file (exists? "project.clj")
          profname (clojure.core/name (key profile))]
      (parse-profile file profname [:profiles (key profile)] (val profile) args)))
  (infoc " "))

(defn- check-path [path args]
  (if-let [file (exists? path)]
    (cond (.isFile file) (parse-profiles file args)
          (.isDirectory file) (doseq [file (filter (comp not directory?) (file-seq-nh file))]
                                (parse-profiled file args)))
    (infoc :yellow "No profile file found at " path "\n")))

(defn run-task [{:keys [root profiles]} args]
  (let [profile-paths (if (and root (exists? root))
                        (conj profile-paths (str root "/profiles.clj"))
                        profile-paths)]
    (doseq [path profile-paths] (check-path path args))
    (parse-project-profiles profiles args)))
